@@ -1,14 +1,14 @@
-from element_is_visible_base import *
-from element_selector import *
-from action_base import *
+import os
+import sys
+sys.path.insert(0,os.path.abspath(__file__+"/../../../"))
+from pyccuracy.page import Page
+from pyccuracy.actions.action_base import ActionBase
+from pyccuracy.actions.element_is_visible_base import *
 
 class ButtonIsNotVisibleAction(ElementIsVisibleBase):
     def __init__(self, browser_driver, language):
         super(ButtonIsNotVisibleAction, self).__init__(browser_driver, language)
 
-    def get_selector(self, element_name):
-        return ElementSelector.button(element_name)
-
     def matches(self, line):
         reg = self.language["button_is_not_visible_regex"]
         self.last_match = reg.search(line)
@@ -17,7 +17,8 @@ class ButtonIsNotVisibleAction(ElementIsVisibleBase):
     def values_for(self, line):
         return self.last_match and (self.last_match.groups()[1],) or tuple([])
 
-    def execute(self, values):
+    def execute(self, values, context):
         button_name = values[0]
+        button = self.resolve_element_key(context, Page.Button, button_name)
         error_message = self.language["button_is_not_visible_failure"]
-        self.execute_is_not_visible(button_name, error_message)
+        self.execute_is_not_visible(context, Page.Button, button_name, error_message)
