@@ -1,6 +1,9 @@
-from pyccuracy.selenium_browser_driver import *
-from element_selector import *
-from action_base import *
+import os
+import sys
+sys.path.insert(0,os.path.abspath(__file__+"/../../../"))
+from pyccuracy.page import Page
+from pyccuracy.actions.action_base import ActionBase
+from pyccuracy.actions.element_is_visible_base import *
 
 class LinkClickAction(ActionBase):
     def __init__(self, browser_driver, language):
@@ -14,9 +17,9 @@ class LinkClickAction(ActionBase):
     def values_for(self, line):
         return self.last_match and (self.last_match.groups()[1],) or tuple([])
 
-    def execute(self, values):
+    def execute(self, values, context):
         link_name = values[0]
-        link = ElementSelector.link(link_name)
+        link = self.resolve_element_key(context, Page.Link, link_name)
         self.assert_element_is_visible(link, self.language["link_is_visible_failure"] % link_name)
         self.browser_driver.click_element(link)
-        self.browser_driver.wait_for_page()
\ No newline at end of file
+        self.browser_driver.wait_for_page()
